@@ -45,7 +45,8 @@ def set_up_cdf_client(context='run'):
         raise ValueError("Context should be either 'run' or 'deploy'")
 
     for k in api_key_labels:
-        global_client[k] = get_client(api_keys[k], k)
+        if k not in global_client:
+            global_client[k] = get_client(api_keys[k], k)
         
     logging.info("CDF client was set up correctly")
 
@@ -68,8 +69,6 @@ def get_client(api_key, api_key_label=None):
     )
     assert client.login.status().logged_in
     logging.debug(f"{client.version=}")
-    logging.debug(f"{client.config.client_name=}")
-    
     return client
 
 
